Changelog
=========

0.1.0 (2016-02-14)
------------------

- Also wait on TCP Check if startsecs have been given.
  [pcdummy]

- Add TCP Check and start_extra.
  [pcdummy]

- Reverse the priority on start.
  [pcdummy]


0.0.1a3 (2016-02-11)
--------------------

- Fix apapvisor config path detection.
  [pcdummy]


0.0.1a2 (2016-02-10)
--------------------

- Fix package installation, move config to ~/.config.
  [pcdummy]

- Add texttable for the status output and psutil for memory info.
  [pcdummy]

- Link pypi, cleanup main().
  [pcdummy]

- Use argparser and smaller bugfixes.
  [pcdummy]

- Use sys.prefix for config files.
  [pcdummy]

- Added support for connecting to 'unix://' sockets.
  [pcdummy]

- Add an option 'enable' to disable projects.
  [pcdummy]

- README.rst, papavisor is available over pip.
  [pcdummy]

- Fix "python3 setup.py develop".
  [pcdummy]


0.0.1a (2016-02-10)
-------------------

- papavisor was born.
  [pcdummy]
